summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jabbertransport.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/protocols/jabber/jabbertransport.h
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/protocols/jabber/jabbertransport.h')
-rw-r--r--kopete/protocols/jabber/jabbertransport.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/kopete/protocols/jabber/jabbertransport.h b/kopete/protocols/jabber/jabbertransport.h
index 605f5cc4..e03be173 100644
--- a/kopete/protocols/jabber/jabbertransport.h
+++ b/kopete/protocols/jabber/jabbertransport.h
@@ -40,29 +40,30 @@ class JabberProtocol;
class JabberTransport : public Kopete::Account
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* constructor called when the transport is created by info from server (i.e not when loading kopete)
* @param parentAccount is the parent jabber account.
* @param item is the roster item of the gateway
* @param gateway_type eg: "msn" or "icq" only used when the account is not loaded from config file for determining the icon
*/
- JabberTransport (JabberAccount * parentAccount, const XMPP::RosterItem &item, const TQString& gateway_type=TQString());
+ JabberTransport (JabberAccount * tqparentAccount, const XMPP::RosterItem &item, const TQString& gateway_type=TQString());
/**
* constructor called when the transport is loaded from config
* @param parentAccount is the parent jabber account.
* @param accountId is the accountId
*/
- JabberTransport (JabberAccount * parentAccount, const TQString &accountId );
+ JabberTransport (JabberAccount * tqparentAccount, const TQString &accountId );
~JabberTransport ();
/** Returns the action menu for this account. */
virtual KActionMenu *actionMenu ();
/** the parent account */
JabberAccount *account() const
{ return m_account; }
@@ -79,8 +80,8 @@ public:
virtual bool removeAccount();
- enum TransportStatus { Normal , Creating, Removing , AccountRemoved };
- TransportStatus transportStatus() { return m_status; };
+ enum TransporttqStatus { Normal , Creating, Removing , AccountRemoved };
+ TransporttqStatus transporttqStatus() { return m_status; };
/**
* return the legacyId conrresponding to the jid
@@ -91,7 +92,7 @@ public:
public slots:
/* Reimplemented from Kopete::Account */
- void setOnlineStatus( const Kopete::OnlineStatus& status , const TQString &reason = TQString::null);
+ void setOnlineStatus( const Kopete::OnlineStatus& status , const TQString &reason = TQString());
/**
* the account has been unregistered.
@@ -122,16 +123,16 @@ protected:
* method should have the "dirty" flag set.
*
* This method should simply be used to intantiate the new contact, everything else
- * (updating the GUI, parenting to meta contact, etc.) is being taken care of.
+ * (updating the GUI, tqparenting to meta contact, etc.) is being taken care of.
*
* @param contactId The unique ID for this protocol
* @param parentContact The metacontact to add this contact to
*/
- virtual bool createContact (const TQString & contactID, Kopete::MetaContact * parentContact);
+ virtual bool createContact (const TQString & contactID, Kopete::MetaContact * tqparentContact);
private:
JabberAccount *m_account;
- TransportStatus m_status;
+ TransporttqStatus m_status;
};
@@ -40,29 +40,30 @@ class JabberProtocol;
/**
* constructor called when the transport is created by info from server (i.e not when loading kopete)
- * @param parentAccount is the parent jabber account.
+ * @param tqparentAccount is the tqparent jabber account.
* @param item is the roster item of the gateway
* @param gateway_type eg: "msn" or "icq" only used when the account is not loaded from config file for determining the icon
@@ -40,29 +40,30 @@ class JabberProtocol;
/**
* constructor called when the transport is loaded from config
- * @param parentAccount is the parent jabber account.
+ * @param tqparentAccount is the tqparent jabber account.
* @param accountId is the accountId
*/
@@ -40,29 +40,30 @@ class JabberProtocol;
/** Returns the action menu for this account. */
virtual KActionMenu *actionMenu ();
- /** the parent account */
+ /** the tqparent account */
JabberAccount *account() const
{ return m_account; }
@@ -122,16 +123,16 @@ protected:
*
* @param contactId The unique ID for this protocol
- * @param parentContact The metacontact to add this contact to
+ * @param tqparentContact The metacontact to add this contact to
*/